@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 
+from datetime import datetime
 
 class MOSPObject:
-    def __int__(self):
+    def __init__(self):
         self.name: str
         self.name: str
-        self.last_updated: date
+        self.last_updated: datetime
         self.json_object: dict
